@@ -31,6 +31,7 @@
 
 #include "server/camel-ews-settings.h"
 #include "server/e-ews-connection.h"
+#include "server/e-ews-connection-utils.h"
 #include "server/e-ews-oof-settings.h"
 #include "camel/camel-ews-store.h"
 
@@ -84,9 +85,9 @@ enum {
 
 /* Forward Declarations */
 static void	e_mail_config_ews_delegates_page_interface_init
-					(EMailConfigPageInterface *interface);
+					(EMailConfigPageInterface *iface);
 static void	e_mail_config_ews_delegates_page_authenticator_init
-					(ESourceAuthenticatorInterface *interface);
+					(ESourceAuthenticatorInterface *iface);
 static void	add_to_tree_view	(EMailConfigEwsDelegatesPage *page,
 					 EwsDelegateInfo *di,
 					 gboolean select);
@@ -1090,8 +1091,7 @@ mail_config_ews_delegates_page_constructed (GObject *object)
 	page = E_MAIL_CONFIG_EWS_DELEGATES_PAGE (object);
 
 	/* Chain up to parent's constructed() method. */
-	G_OBJECT_CLASS (e_mail_config_ews_delegates_page_parent_class)->
-		constructed (object);
+	G_OBJECT_CLASS (e_mail_config_ews_delegates_page_parent_class)->constructed (object);
 
 	gtk_box_set_spacing (GTK_BOX (page), 12);
 
@@ -1499,6 +1499,20 @@ sort_by_display_name_cb (gconstpointer a,
 	return g_utf8_collate (aname, bname);
 }
 
+static gboolean
+mail_config_ews_delegates_page_get_without_password (ESourceAuthenticator *auth)
+{
+	EMailConfigEwsDelegatesPage *page;
+	CamelSettings *settings;
+	CamelEwsSettings *ews_settings;
+
+	page = E_MAIL_CONFIG_EWS_DELEGATES_PAGE (auth);
+	settings = mail_config_ews_delegates_page_get_settings (page);
+	ews_settings = CAMEL_EWS_SETTINGS (settings);
+
+	return e_ews_connection_utils_get_without_password (ews_settings);
+}
+
 static ESourceAuthenticationResult
 mail_config_ews_delegates_page_try_password_sync (ESourceAuthenticator *auth,
                                                   const GString *password,
@@ -1625,18 +1639,21 @@ e_mail_config_ews_delegates_page_class_init (EMailConfigEwsDelegatesPageClass *c
 }
 
 static void
-e_mail_config_ews_delegates_page_interface_init (EMailConfigPageInterface *interface)
+e_mail_config_ews_delegates_page_interface_init (EMailConfigPageInterface *iface)
 {
-	interface->title = _("Delegates");
-	interface->sort_order = E_MAIL_CONFIG_EWS_DELEGATES_PAGE_SORT_ORDER;
-	interface->submit = mail_config_ews_delegates_page_submit;
-	interface->submit_finish = mail_config_ews_delegates_page_submit_finish;
+	iface->title = _("Delegates");
+	iface->sort_order = E_MAIL_CONFIG_EWS_DELEGATES_PAGE_SORT_ORDER;
+	iface->submit = mail_config_ews_delegates_page_submit;
+	iface->submit_finish = mail_config_ews_delegates_page_submit_finish;
 }
 
 static void
-e_mail_config_ews_delegates_page_authenticator_init (ESourceAuthenticatorInterface *interface)
+e_mail_config_ews_delegates_page_authenticator_init (ESourceAuthenticatorInterface *iface)
 {
-	interface->try_password_sync = mail_config_ews_delegates_page_try_password_sync;
+	iface->get_without_password =
+		mail_config_ews_delegates_page_get_without_password;
+	iface->try_password_sync =
+		mail_config_ews_delegates_page_try_password_sync;
 }
 
 static void
