@@ -48,8 +48,6 @@ struct _EEwsFolderPrivate {
 	gboolean foreign;
 };
 
-static GObjectClass *parent_class = NULL;
-
 static void
 e_ews_folder_dispose (GObject *object)
 {
@@ -57,8 +55,7 @@ e_ews_folder_dispose (GObject *object)
 
 	g_return_if_fail (E_IS_EWS_FOLDER (folder));
 
-	if (parent_class->dispose)
-		(* parent_class->dispose) (object);
+	G_OBJECT_CLASS (e_ews_folder_parent_class)->dispose (object);
 }
 
 static void
@@ -92,11 +89,7 @@ e_ews_folder_finalize (GObject *object)
 		priv->parent_fid = NULL;
 	}
 
-	g_free (priv);
-	folder->priv = NULL;
-
-	if (parent_class->finalize)
-		(* parent_class->finalize) (object);
+	G_OBJECT_CLASS (e_ews_folder_parent_class)->finalize (object);
 }
 
 static void
@@ -104,7 +97,7 @@ e_ews_folder_class_init (EEwsFolderClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
+	g_type_class_add_private (klass, sizeof (EEwsFolderPrivate));
 
 	object_class->dispose = e_ews_folder_dispose;
 	object_class->finalize = e_ews_folder_finalize;
@@ -113,15 +106,10 @@ e_ews_folder_class_init (EEwsFolderClass *klass)
 static void
 e_ews_folder_init (EEwsFolder *folder)
 {
-	EEwsFolderPrivate *priv;
-
-	/* allocate internal structure */
-	priv = g_new0 (EEwsFolderPrivate, 1);
-	folder->priv = priv;
-
-	priv->error = NULL;
-	priv->folder_type = E_EWS_FOLDER_TYPE_UNKNOWN;
-	priv->foreign = FALSE;
+	folder->priv = G_TYPE_INSTANCE_GET_PRIVATE (folder, E_TYPE_EWS_FOLDER, EEwsFolderPrivate);
+	folder->priv->error = NULL;
+	folder->priv->folder_type = E_EWS_FOLDER_TYPE_UNKNOWN;
+	folder->priv->foreign = FALSE;
 }
 
 static gboolean
@@ -317,7 +305,7 @@ e_ews_folder_is_error (EEwsFolder *folder)
 }
 
 const GError *
-e_ews_folder_get_error (EEwsFolder *folder)
+e_ews_folder_get_error (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), NULL);
 
@@ -374,7 +362,7 @@ e_ews_folder_id_is_equal (const EwsFolderId *a,
 }
 
 const gchar *
-e_ews_folder_get_name (EEwsFolder *folder)
+e_ews_folder_get_name (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), NULL);
 
@@ -397,7 +385,7 @@ e_ews_folder_set_name (EEwsFolder *folder,
 }
 
 const EwsFolderId *
-e_ews_folder_get_id (EEwsFolder *folder)
+e_ews_folder_get_id (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), NULL);
 
@@ -405,7 +393,7 @@ e_ews_folder_get_id (EEwsFolder *folder)
 }
 
 const EwsFolderId *
-e_ews_folder_get_parent_id (EEwsFolder *folder)
+e_ews_folder_get_parent_id (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), NULL);
 
@@ -433,7 +421,7 @@ e_ews_folder_set_parent_id (EEwsFolder *folder,
 }
 
 EEwsFolderType
-e_ews_folder_get_folder_type (EEwsFolder *folder)
+e_ews_folder_get_folder_type (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), -1);
 
@@ -450,7 +438,7 @@ e_ews_folder_set_folder_type (EEwsFolder *folder,
 }
 
 guint32
-e_ews_folder_get_total_count (EEwsFolder *folder)
+e_ews_folder_get_total_count (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), -1);
 
@@ -458,7 +446,7 @@ e_ews_folder_get_total_count (EEwsFolder *folder)
 }
 
 guint32
-e_ews_folder_get_unread_count (EEwsFolder *folder)
+e_ews_folder_get_unread_count (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), -1);
 
@@ -466,7 +454,7 @@ e_ews_folder_get_unread_count (EEwsFolder *folder)
 }
 
 guint32
-e_ews_folder_get_child_count (EEwsFolder *folder)
+e_ews_folder_get_child_count (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), -1);
 
@@ -474,7 +462,7 @@ e_ews_folder_get_child_count (EEwsFolder *folder)
 }
 
 guint64
-e_ews_folder_get_size (EEwsFolder *folder)
+e_ews_folder_get_size (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), -1);
 
@@ -482,7 +470,7 @@ e_ews_folder_get_size (EEwsFolder *folder)
 }
 
 gboolean
-e_ews_folder_get_foreign (EEwsFolder *folder)
+e_ews_folder_get_foreign (const EEwsFolder *folder)
 {
 	g_return_val_if_fail (E_IS_EWS_FOLDER (folder), FALSE);
 
