@@ -60,23 +60,23 @@ EEwsFolderType	e_ews_folder_type_from_nick (const gchar *folder_type_nick);
 EEwsFolder *	e_ews_folder_new_from_soap_parameter (ESoapParameter *param);
 EEwsFolder *	e_ews_folder_new_from_error (const GError *error);
 gboolean	e_ews_folder_is_error (EEwsFolder *folder);
-const GError *	e_ews_folder_get_error (EEwsFolder *folder);
-const gchar *	e_ews_folder_get_name (EEwsFolder *folder);
+const GError *	e_ews_folder_get_error (const EEwsFolder *folder);
+const gchar *	e_ews_folder_get_name (const EEwsFolder *folder);
 void		e_ews_folder_set_name (EEwsFolder *folder, const gchar *new_name);
 void		e_ews_folder_set_parent_id (EEwsFolder *folder, EwsFolderId *fid);
 const EwsFolderId *
-		e_ews_folder_get_parent_id (EEwsFolder *folder);
+		e_ews_folder_get_parent_id (const EEwsFolder *folder);
 const EwsFolderId *
-		e_ews_folder_get_id (EEwsFolder *folder);
-guint32		e_ews_folder_get_total_count (EEwsFolder *folder);
-guint32		e_ews_folder_get_unread_count (EEwsFolder *folder);
-guint32		e_ews_folder_get_child_count (EEwsFolder *folder);
-guint64		e_ews_folder_get_size (EEwsFolder *folder);
-gboolean	e_ews_folder_get_is_writable (EEwsFolder *folder);
+		e_ews_folder_get_id (const EEwsFolder *folder);
+guint32		e_ews_folder_get_total_count (const EEwsFolder *folder);
+guint32		e_ews_folder_get_unread_count (const EEwsFolder *folder);
+guint32		e_ews_folder_get_child_count (const EEwsFolder *folder);
+guint64		e_ews_folder_get_size (const EEwsFolder *folder);
+gboolean	e_ews_folder_get_is_writable (const EEwsFolder *folder);
 void		e_ews_folder_set_is_writable (EEwsFolder *folder, gboolean writable);
-EEwsFolderType	e_ews_folder_get_folder_type (EEwsFolder *folder);
+EEwsFolderType	e_ews_folder_get_folder_type (const EEwsFolder *folder);
 void		e_ews_folder_set_folder_type (EEwsFolder *folder, EEwsFolderType folder_type);
-gboolean	e_ews_folder_get_foreign (EEwsFolder *folder);
+gboolean	e_ews_folder_get_foreign (const EEwsFolder *folder);
 void		e_ews_folder_set_foreign (EEwsFolder *folder, gboolean is_foreign);
 
 EwsFolderId *	e_ews_folder_id_new (const gchar *id,
